@@ -1,6 +1,7 @@
 #ifndef _LIBHX_IO_H
 #define _LIBHX_IO_H 1
 
+#include <stdio.h>
 #include <sys/types.h>
 
 #ifdef __cplusplus
@@ -35,9 +36,16 @@ extern int HX_mkdir(const char *, unsigned int);
 extern int HX_readlink(hxmc_t **, const char *);
 extern int HX_realpath(hxmc_t **, const char *, unsigned int);
 extern int HX_rrmdir(const char *);
+extern ssize_t HX_sendfile(int dst, int src, size_t count);
+extern char *HX_slurp_fd(int fd, size_t *outsize);
+extern char *HX_slurp_file(const char *file, size_t *outsize);
 
 extern ssize_t HXio_fullread(int, void *, size_t);
 extern ssize_t HXio_fullwrite(int, const void *, size_t);
+#ifndef HX_HEXDUMP_DECLARATION
+#define HX_HEXDUMP_DECLARATION 1
+extern void HX_hexdump(FILE *, const void *, unsigned int);
+#endif
 
 #ifdef __cplusplus
 } /* extern "C" */
